Serialization - kombu.serialization — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Serialization - kombu.serialization

Centralized support for encoding/decoding of data structures. Requires a json library (cjson, simplejson, or Python 2.6+).

Pickle support is built-in.

Optionally installs support for `YAML` if the PyYAML package is installed.

Optionally installs support for msgpack if the msgpack-python package is installed.

exception `kombu.serialization.` `SerializerNotInstalled`

  Support for the requested serialization type is not installed

`kombu.serialization.` `registry`
  `kombu.serialization.` `encode`(data, serializer=default_serializer)

  Encode data using the registry’s default encoder.

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »